[Returnanalytics-commits] r2868 - in pkg/FactorAnalytics: R man

noreply at r-forge.r-project.org noreply at r-forge.r-project.org
Sat Aug 24 01:37:10 CEST 2013


Author: chenyian
Date: 2013-08-24 01:37:10 +0200 (Sat, 24 Aug 2013)
New Revision: 2868

Modified:
   pkg/FactorAnalytics/R/factorModelEsDecomposition.R
   pkg/FactorAnalytics/R/factorModelSdDecomposition.R
   pkg/FactorAnalytics/R/factorModelVaRDecomposition.R
   pkg/FactorAnalytics/man/factorModelEsDecomposition.Rd
   pkg/FactorAnalytics/man/factorModelSdDecomposition.Rd
   pkg/FactorAnalytics/man/factorModelVaRDecomposition.Rd
Log:
clean up variable names. 

Modified: pkg/FactorAnalytics/R/factorModelEsDecomposition.R
===================================================================
--- pkg/FactorAnalytics/R/factorModelVaRDecomposition.R	2013-08-23 19:42:35 UTC (rev 2867)
+++ pkg/FactorAnalytics/R/factorModelVaRDecomposition.R	2013-08-23 23:37:10 UTC (rev 2868)
@@ -29,7 +29,7 @@
 #' exceedences.
 #' \item{mVaR.fm} (K+1) x 1 vector of factor marginal contributions to VaR.
 #' \item{cVaR.fm} (K+1) x 1 vector of factor component contributions to VaR.
-#' \item{pcVaR.fm} (K+1) x 1 vector of factor percent contributions to VaR.
+#' \item{pcVaR.fm} (K+1) x 1 vector of factor percentage contributions to VaR.
 #' }
 #' @author Eric Zivot and Yi-An Chen
 #' @references 1. Hallerback (2003), "Decomposing Portfolio Value-at-Risk: A

Modified: pkg/FactorAnalytics/man/factorModelEsDecomposition.Rd
===================================================================
--- pkg/FactorAnalytics/man/factorModelEsDecomposition.Rd	2013-08-23 19:42:35 UTC (rev 2867)
+++ pkg/FactorAnalytics/man/factorModelEsDecomposition.Rd	2013-08-23 23:37:10 UTC (rev 2868)
@@ -35,11 +35,12 @@
   number of observations beyond VaR. \item{idx.exceed}
   \code{n.exceed x 1} vector giving index values of
   exceedences. \item{ES scalar} nonparametric ES value for
-  fund reported as a positive number. \item{mcES}
+  fund reported as a positive number. \item{mES}
   \code{(K+1) x 1} vector of factor marginal contributions
   to ES. \item{cES} \code{(K+1) x 1} vector of factor
   component contributions to ES. \item{pcES} \code{(K+1) x
-  1} vector of factor percent contributions to ES. }
+  1} vector of factor percentage component contributions to
+  ES. }
 }
 \description{
   Compute the factor model factor expected shortfall (ES)

Modified: pkg/FactorAnalytics/man/factorModelSdDecomposition.Rd
===================================================================
--- pkg/FactorAnalytics/man/factorModelSdDecomposition.Rd	2013-08-23 19:42:35 UTC (rev 2867)
+++ pkg/FactorAnalytics/man/factorModelSdDecomposition.Rd	2013-08-23 23:37:10 UTC (rev 2868)
@@ -15,12 +15,13 @@
   model.}
 }
 \value{
-  an S3 object containing \itemize{ \item{sd.fm} Scalar,
-  std dev based on factor model. \item{mcr.fm} (K+1) x 1
+  an S3 object containing \itemize{ \item{Sd.fm} Scalar,
+  std dev based on factor model. \item{mSd.fm} (K+1) x 1
   vector of factor marginal contributions to risk sd.
-  \item{cr.fm} (K+1) x 1 vector of factor component
-  contributions to risk sd. \item{pcr.fm} (K+1) x 1 vector
-  of factor percent contributions to risk sd. }
+  \item{cSd.fm} (K+1) x 1 vector of factor component
+  contributions to risk sd. \item{pcSd.fm} (K+1) x 1 vector
+  of factor percentage component contributions to risk sd.
+  }
 }
 \description{
   Compute factor model factor risk (sd) decomposition for

Modified: pkg/FactorAnalytics/man/factorModelVaRDecomposition.Rd
===================================================================
--- pkg/FactorAnalytics/man/factorModelVaRDecomposition.Rd	2013-08-23 19:42:35 UTC (rev 2867)
+++ pkg/FactorAnalytics/man/factorModelVaRDecomposition.Rd	2013-08-23 23:37:10 UTC (rev 2868)
@@ -34,7 +34,7 @@
   vector of factor marginal contributions to VaR.
   \item{cVaR.fm} (K+1) x 1 vector of factor component
   contributions to VaR. \item{pcVaR.fm} (K+1) x 1 vector of
-  factor percent contributions to VaR. }
+  factor percentage contributions to VaR. }
 }
 \description{
   Compute factor model factor VaR decomposition based on



More information about the Returnanalytics-commits mailing list
--- pkg/FactorAnalytics/R/factorModelEsDecomposition.R	2013-08-23 19:42:35 UTC (rev 2867)
+++ pkg/FactorAnalytics/R/factorModelEsDecomposition.R	2013-08-23 23:37:10 UTC (rev 2868)
@@ -32,9 +32,9 @@
 #' \item{n.exceed} Scalar, number of observations beyond VaR.
 #' \item{idx.exceed} \code{n.exceed x 1} vector giving index values of exceedences.
 #' \item{ES scalar} nonparametric ES value for fund reported as a positive number.
 #' \item{mcES} \code{(K+1) x 1} vector of factor marginal contributions to ES.
 #' \item{cES} \code{(K+1) x 1} vector of factor component contributions to ES.
-#' \item{pcES} \code{(K+1) x 1} vector of factor percent contributions to ES.
+#' \item{pcES} \code{(K+1) x 1} vector of factor percentage component contributions to ES.
 #' }
 #' @author Eric Zviot and Yi-An Chen.
 #' @references 1. Hallerback (2003), "Decomposing Portfolio Value-at-Risk: A
@@ -123,7 +123,7 @@
            n.exceed = length(idx),
            idx.exceed = idx,
            ES = ES.fm, 
-           mcES = t(mcES.fm), 
+           mES = t(mcES.fm), 
            cES = t(cES.fm),
            pcES = t(pcES.fm))
 return(ans)
@@ -32,9 +32,9 @@
 #' \item{idx.exceed} \code{n.exceed x 1} vector giving index values of exceedences.
 #' \item{ES scalar} nonparametric ES value for fund reported as a positive number.
-#' \item{mcES} \code{(K+1) x 1} vector of factor marginal contributions to ES.
+#' \item{mES} \code{(K+1) x 1} vector of factor marginal contributions to ES.
 #' \item{cES} \code{(K+1) x 1} vector of factor component contributions to ES.

Modified: pkg/FactorAnalytics/R/factorModelSdDecomposition.R
===================================================================
--- pkg/FactorAnalytics/R/factorModelSdDecomposition.R	2013-08-23 19:42:35 UTC (rev 2867)
+++ pkg/FactorAnalytics/R/factorModelSdDecomposition.R	2013-08-23 23:37:10 UTC (rev 2868)
@@ -9,10 +9,10 @@
 #' @param sig2.e scalar, residual variance from factor model.
 #' @return an S3 object containing
 #' \itemize{
 #' \item{sd.fm} Scalar, std dev based on factor model.
 #' \item{mcr.fm} (K+1) x 1 vector of factor marginal contributions to risk sd.
 #' \item{cr.fm} (K+1) x 1 vector of factor component contributions to risk sd.
 #' \item{pcr.fm} (K+1) x 1 vector of factor percent contributions to risk sd.
 #' }
 #' @author Eric Zivot and Yi-An Chen
 #' @examples
@@ -67,10 +67,10 @@
 	colnames(cr.fm) = "CR"
 	colnames(pcr.fm) = "PCR"
 ## return results
-	ans = list(sd.fm = sd.fm,
-             mcr.fm = t(mcr.fm),
-             cr.fm = t(cr.fm),
-             pcr.fm = t(pcr.fm))
+	ans = list(Sd.fm = sd.fm,
+             mSd.fm = t(mcr.fm),
+             cSd.fm = t(cr.fm),
+             pcSd.fm = t(pcr.fm))
 	return(ans)
 }
 
@@ -9,10 +9,10 @@
 #' @return an S3 object containing
 #' \itemize{
-#' \item{sd.fm} Scalar, std dev based on factor model.
-#' \item{mcr.fm} (K+1) x 1 vector of factor marginal contributions to risk sd.
-#' \item{cr.fm} (K+1) x 1 vector of factor component contributions to risk sd.
-#' \item{pcr.fm} (K+1) x 1 vector of factor percent contributions to risk sd.
+#' \item{Sd.fm} Scalar, std dev based on factor model.
+#' \item{mSd.fm} (K+1) x 1 vector of factor marginal contributions to risk sd.
+#' \item{cSd.fm} (K+1) x 1 vector of factor component contributions to risk sd.
+#' \item{pcSd.fm} (K+1) x 1 vector of factor percentage component contributions to risk sd.
 #' }
 #' @author Eric Zivot and Yi-An Chen

Modified: pkg/FactorAnalytics/R/factorModelVaRDecomposition.R
===================================================================